#
# spec file for package tcpreplay
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           tcpreplay
Version:        4.2.6
Release:        lp150.1.3
Summary:        Network analysis and testing tools
License:        GPL-3.0
Group:          Productivity/Networking/Diagnostic
Url:            http://tcpreplay.appneta.com/
Source0:        https://github.com/appneta/tcpreplay/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/appneta/tcpreplay/releases/download/v%{version}/%{name}-%{version}.tar.gz.asc
Source2:        %{name}.keyring
BuildRequires:  dbus-1-devel
BuildRequires:  libdnet-devel
BuildRequires:  libpcap-devel
%if 0%{?suse_version} > 1110
BuildRequires:  libnl3-devel
%endif
BuildRequires:  tcpdump
Requires:       tcpdump
# only needed for suse_version < 1130 (i.e. SLE11)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Tcpreplay is a suite of utilities for editing and replaying
previously captured network traffic. It was originally designed to
replay malicious traffic patterns to Intrusion Detection/Prevention
Systems, and is meanwhile capable of replaying to web servers. It
supports switches, routers and IP Flow/NetFlow appliances.

%prep
%setup -q

%build
%configure \
  --enable-dynamic-link
make %{?_smp_mflags} V=1

%install
%make_install

%files
%defattr(-,root,root)
%doc docs/LICENSE
%doc docs/CHANGELOG
%{_bindir}/*
%{_mandir}/man1/*

%changelog
* Mon Sep 11 2017 jengelh@inai.de
- Trim history recap in description.
* Mon Jul 31 2017 mpluskal@suse.com
- Update to version 4.2.6:
  * Test fails on sparc64 (#393)
- Changes for version 4.2.5:
  * Fix issues found by scan-build (#384)
  * Improve --portmap help message (#381)
  * AFL detected security crash in fuzz feature (#380)
  * Coverity static scan detected issues (#374)
  * Fuzz should not be overwritting Layer 3 (#372)
  * Add --fuzz-factor option to specify fuzz ratio (#371)
  * Warnings when building on old distributions (#368)
  * Fix more Lintian detected spelling errors (#365)
  * Fuzz test failure on ARM and MIPS (#364)
- Changes for version 4.2.4:
  * Fix Lintian detected spelling errors (#362)
- Changes for version 4.2.3:
  * Archive (remove) QuickTX until maintainer found (#357)
  * Ubuntu precise 32bit_build (#356)
- Changes for version 4.2.2:
  * Archive (remove) QuickTX (#357)
  * Missing symbol pcap_version on macOS 10.12.4 (#356)
- Changes for version 4.2.1:
  * Fix reporting of rates < 1Mbps (#348)
  * Option --unique-ip not working properly (#346)
- Changes for version 4.2.0:
  * MAC rewriting capabilities (#313)
  * Fix several issues identified by Coverity (#305)
  * Packet destortion --fuzz-seed option by Gabriel Ganne (#302)
  * Add --unique-ip-loops option to modify IPs every few loops
    (#296)
  * Netmap startup delay increase (#290)
  * tcpcapinfo buffer overflow vulnerablily (#278)
  * Update git-clone instructions by Kyle McDonald (#277)
  * Allow fractions for --pps option (#270)
  * Print per-loop stats with --stats=0 (#269)
  * Add protection against packet drift by Guillaume Scott (#268)
  * Print flow stats periodically with --stats output (#262)
  * Include Travis-CI build support by Ilya Shipitsin (#264) (#285)
  * tcpreplay won't replay all packets in a pcap file with --netmap
    (#255)
  * First and last packet times in --stats output (#239)
  * Switch to wire speed after 30 minutes at 6 Gbps (#210)
  * tcprewrite fix checksum properly for fragmented packets (#190)
- Drop no longer needed patch (already in upstream):
  * 278-fail-if-capture-has-a-packet-that-is-too-large.patch
- Use %%make_install macro
- Update dependencies to support (libnl3 and dbus-1)
* Thu Mar 16 2017 mkubecek@suse.cz
- 278-fail-if-capture-has-a-packet-that-is-too-large.patch:
  buffer overflow in tcpcapinfo utility triggered by too large
  packet (CVE-2017-6429 bsc#1028234)
* Mon Nov 21 2016 mkubecek@suse.cz
- update to version 4.1.2
  * increase max packet size to 65549 (CVE-2016-6160 bsc#987846)
  * minor build fixes
* Wed Feb  3 2016 mkubecek@suse.cz
- add upstream changelog to docs
- minor specfile cleanup
* Sun Jan 31 2016 mpluskal@suse.com
- Install LICENSE
- Use url for source
- Add gpg signature
- Make building more verbose
- Cleanup spec file with spec-cleaner
* Thu Jan 28 2016 mkubecek@suse.cz
- run specfile through cleaner service to silence check scripts
* Tue Jan 12 2016 mkubecek@suse.cz
- update to version 4.1.1
  * various fixes
  * performance improvements
  * add --duration option which lets the user set the number of
    seconds to transmit
  * do not require --loop for --unique-ip
  * tun/tap support
  * support multiple CIDR ranges with tcprewrite
* Mon Mar  9 2015 mkubecek@suse.cz
- upgrade to version 4.1.0
  * Quick TX bypass module for Linux Kernel - allows Tcpreplay to
    bypass the kernel network stack and write directly to the
    network driver (disabled for now)
  * add a flag to customize netmap delay
  * add a loop delay option
  * fix: segfault in tcpliveplay on x86_64
  * fix: sometimes unable to interrupt with Ctrl-C
* Tue Nov 25 2014 mkubecek@suse.cz
- upgrade to version 4.0.5
  * various bugfixes; for details see
    https://github.com/appneta/tcpreplay/releases/tag/v4.0.5
* Wed May 28 2014 mkubecek@suse.cz
- upgrade to version 4.0.4
  * performance enhancements
  * IP flow / Netflow features
  * support netmap network drivers
  * new API
  * ARM support
  * new DLT support
- tcpreplay-3.4.4-overflow.patch:
  delete (no longer needed)
* Mon Nov 18 2013 mkubecek@suse.cz
- dynamic linking of libraries (fix build on >= 12.3)
* Thu Nov  3 2011 mkubecek@suse.cz
- initial package
- patch for buffer overflow in cidr2iplist()
